pub struct Args {
pub net: Network,
pub time_source: BlockTemplateTimeSource,
pub template: Option<String>,
}Expand description
block-template-to-proposal arguments
Fields
net: NetworkThe network to use for the block proposal.
time_source: BlockTemplateTimeSourceThe source of the time in the block proposal header.
Format: “curtime”, “mintime”, “maxtime”, [“clamped”]u32, “raw“u32
Clamped times are clamped to the template’s [mintime, maxtime].
Raw times are used unmodified: this can produce invalid proposals.
template: Option<String>The JSON block template. If this argument is not supplied, the template is read from standard input.
The template and proposal structures are printed to stderr.